==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QAccessible_ActivationObserver_shell.cpp <==
#include "QAccessible_ActivationObserver_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessible_ActivationObserver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessible::ActivationObserver")
    QAccessible::ActivationObserver *_ptr = reinterpret_cast<QAccessible::ActivationObserver *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessible$ActivationObserver_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessible$ActivationObserver_shell) ); }

jmethodID QAccessible$ActivationObserver_shell::__shell_javaMethod(int pos) const { return QAccessible$ActivationObserver_shell::__shell()->javaMethod(typeid(QAccessible::ActivationObserver), pos); }

// emitting (writeShellConstructor)
QAccessible$ActivationObserver_shell::QAccessible$ActivationObserver_shell()
    : QAccessible::ActivationObserver()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessible::ActivationObserver::QAccessible$ActivationObserver_shell()", QAccessible$ActivationObserver_shell::__shell())
    QAccessible$ActivationObserver_shell::__shell()->constructed(typeid(QAccessible::ActivationObserver));
}

// emitting (writeShellDestructor)
QAccessible$ActivationObserver_shell::~QAccessible$ActivationObserver_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessible::ActivationObserver::~QAccessible::ActivationObserver()", QAccessible$ActivationObserver_shell::__shell())
    QAccessible$ActivationObserver_shell::__shell()->destructed(typeid(QAccessible::ActivationObserver));
}

void QAccessible$ActivationObserver_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessible$ActivationObserver_shell*>(ptr)->QAccessible$ActivationObserver_shell::__shell()->tryDeleteShell(typeid(QAccessible::ActivationObserver));
}

// emitting Virtual overrides (virtualFunctions)
void QAccessible$ActivationObserver_shell::accessibilityActiveChanged(bool active0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessible::ActivationObserver::", QAccessible$ActivationObserver_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessible$ActivationObserver_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, active0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAccessible$ActivationObserver_shell::__shell()->warnForMethod("QAccessible::ActivationObserver::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessible::ActivationObserver::");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAccessible$ActivationObserver_access::__qt_accessibilityActiveChanged_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean active0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessible::ActivationObserver::accessibilityActiveChanged(bool active)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessible::ActivationObserver::accessibilityActiveChanged(bool active).";
    } else {
        accessibilityActiveChanged(static_cast<bool>(active0));
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QAccessible_ActivationObserver_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QAccessible::ActivationObserver *__qt_this = new(__qtjambi_ptr) QAccessible$ActivationObserver_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QAccessible$ActivationObserver_shell
void __qt_destruct_QAccessible_ActivationObserver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessible::ActivationObserver")
    reinterpret_cast<QAccessible$ActivationObserver_shell*>(ptr)->~QAccessible$ActivationObserver_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessible::ActivationObserver::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessible_00024ActivationObserver_00024Impl_initialize_1native__Lio_qt_gui_QAccessible_00024ActivationObserver_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessible::ActivationObserver::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessible_ActivationObserver_0, sizeof(QAccessible$ActivationObserver_shell), typeid(QAccessible::ActivationObserver), true, &deleter_QAccessible_ActivationObserver, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessible::ActivationObserver::accessibilityActiveChanged(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessible_00024ActivationObserver_00024Impl_00024ConcreteWrapper_accessibilityActiveChanged_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jboolean active0)
{
    QTJAMBI_TRY {
        QAccessible::ActivationObserver *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessible::ActivationObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessible::ActivationObserver::accessibilityActiveChanged(bool)", __qt_this)
        static_cast<QAccessible$ActivationObserver_access*>(__qt_this)->__qt_accessibilityActiveChanged_bool(__jni_env, __this_nativeId, active0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessible_ActivationObserver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QAccessible::ActivationObserver>("QAccessible::ActivationObserver", "io/qt/gui/QAccessible$ActivationObserver");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibilityActiveChanged", "(Z)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessible_ActivationObserver, {
        ConstructorInfo(&__qt_construct_QAccessible_ActivationObserver_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessible_ActivationObserver);
    registerSizeOfShell(typeId, sizeof(QAccessible$ActivationObserver_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QAccessible::ActivationObserver* _object = dynamic_cast<QAccessible::ActivationObserver*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QAccessible::ActivationObserver *object = reinterpret_cast<QAccessible::ActivationObserver *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QAccessible::ActivationObserver *object = reinterpret_cast<const QAccessible::ActivationObserver *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QAccessible_ActivationObserver_shell.cpp <==
#include "QAccessible_ActivationObserver_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessible_ActivationObserver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessible::ActivationObserver")
    QAccessible::ActivationObserver *_ptr = reinterpret_cast<QAccessible::ActivationObserver *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessible$ActivationObserver_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessible$ActivationObserver_shell) ); }

jmethodID QAccessible$ActivationObserver_oshell::__shell_javaMethod(int pos) const { return QAccessible$ActivationObserver_shell::__shell()->javaMethod(typeid(QAccessible::ActivationObserver), pos); }

// emitting (writeShellDestructor)
QAccessible$ActivationObserver_shell::~QAccessible$ActivationObserver_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessible::ActivationObserver::~QAccessible::ActivationObserver()", this)
    QAccessible$ActivationObserver_shell::__shell()->destructed(typeid(QAccessible::ActivationObserver));
}

// emitting (writeShellConstructor)
QAccessible$ActivationObserver_shell::QAccessible$ActivationObserver_shell()
    : QAccessible::ActivationObserver()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessible::ActivationObserver::QAccessible$ActivationObserver_shell()", this)
    QAccessible$ActivationObserver_shell::__shell()->constructed(typeid(QAccessible::ActivationObserver));
}

void QAccessible$ActivationObserver_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessible$ActivationObserver_oshell*>(ptr)->QAccessible$ActivationObserver_oshell::__shell()->tryDeleteShell(typeid(QAccessible::ActivationObserver));
}

// emitting Virtual overrides (virtualFunctions)
void QAccessible$ActivationObserver_oshell::accessibilityActiveChanged(bool active0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessible::ActivationObserver::accessibilityActiveChanged(bool)", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessible$ActivationObserver_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, active0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAccessible$ActivationObserver_shell::__shell()->warnForMethod("QAccessible::ActivationObserver::accessibilityActiveChanged(bool)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessible::ActivationObserver::accessibilityActiveChanged(bool)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QAccessible$ActivationObserver_access::__qt_accessibilityActiveChanged_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean active0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QAccessible::ActivationObserver::accessibilityActiveChanged(bool active)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QAccessible::ActivationObserver::accessibilityActiveChanged(bool active).";
    } else {
        accessibilityActiveChanged(static_cast<bool>(active0));
    }
}

// emitting (writeConstructors)
// new ActivationObserver()
void __qt_construct_QAccessible_ActivationObserver(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ActivationObserver()")
    Q_UNUSED(__java_arguments)
    QAccessible::ActivationObserver *__qt_this = new(__qtjambi_ptr) QAccessible$ActivationObserver_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QAccessible::ActivationObserver::ActivationObserver()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessible_00024ActivationObserver_00024Impl_initialize_1native__Lio_qt_gui_QAccessible_00024ActivationObserver_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessible::ActivationObserver::ActivationObserver()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessible_ActivationObserver, sizeof(QAccessible$ActivationObserver_shell), typeid(QAccessible::ActivationObserver), 0, true, &deleter_QAccessible_ActivationObserver, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessible$ActivationObserver_shell
void __qt_destruct_QAccessible_ActivationObserver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessible::ActivationObserver")
    reinterpret_cast<QAccessible$ActivationObserver_shell*>(ptr)->~QAccessible$ActivationObserver_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessible::ActivationObserver::accessibilityActiveChanged(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessible_00024ActivationObserver_00024Impl_00024ConcreteWrapper_accessibilityActiveChanged_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jboolean active0)
{
    QTJAMBI_TRY {
        QAccessible::ActivationObserver *__qt_this = QtJambiAPI::interfaceFromNativeId<QAccessible::ActivationObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessible::ActivationObserver::accessibilityActiveChanged(bool)", __this_nativeId)
        static_cast<QAccessible$ActivationObserver_access*>(__qt_this)->__qt_accessibilityActiveChanged_bool(__jni_env, __this_nativeId, active0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessible_ActivationObserver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QAccessible::ActivationObserver>("QAccessible::ActivationObserver", "io/qt/gui/QAccessible$ActivationObserver");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibilityActiveChanged", "(Z)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QAccessible_ActivationObserver, {
        ConstructorInfo(&__qt_construct_QAccessible_ActivationObserver, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessible_ActivationObserver);
    registerSizeOfShell(typeId, sizeof(QAccessible$ActivationObserver_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QAccessible::ActivationObserver* _object = dynamic_cast<QAccessible::ActivationObserver*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QAccessible::ActivationObserver *object = reinterpret_cast<QAccessible::ActivationObserver *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QAccessible::ActivationObserver *object = reinterpret_cast<const QAccessible::ActivationObserver *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
